@@ -33,9 +33,7 @@ from typing import Dict
 
 import simple_http_server.http_server as http_server
 
-from simple_http_server import _get_filters
-from simple_http_server import _get_request_mappings
-from simple_http_server import _get_websocket_handlers
+from simple_http_server import _get_filters, _get_request_mappings, _get_websocket_handlers, _get_error_pages
 from simple_http_server import request_map
 from simple_http_server import StaticFile
 from simple_http_server.logger import get_logger
@@ -43,7 +41,7 @@ from simple_http_server.logger import get_logger
 
 __logger = get_logger("simple_http_server.server")
 __lock = threading.Lock()
-__server = None
+_server = None
 
 
 def _is_match(string="", regx=r""):
@@ -86,14 +84,17 @@ def _import_module(mname):
     try:
         importlib.import_module(mname)
     except:
-        __logger.warn(f"Import moudle [{mname}] error!")
+        __logger.warning(f"Import moudle [{mname}] error!")
 
 
-def scan(base_dir: str = "", regx: str = r"") -> None:
-    ft = inspect.currentframe()
-    fts = inspect.getouterframes(ft)
-    entrance = fts[-1]
-    work_dir = os.path.dirname(inspect.getabsfile(entrance[0]))
+def scan(base_dir: str = "", regx: str = r"", project_dir: str = "") -> None:
+    if project_dir:
+        work_dir = project_dir
+    else:
+        ft = inspect.currentframe()
+        fts = inspect.getouterframes(ft)
+        entrance = fts[-1]
+        work_dir = os.path.dirname(inspect.getabsfile(entrance[0]))
     modules = _load_all_modules(work_dir, base_dir, regx)
 
     for mname in modules:
@@ -112,48 +113,80 @@ def start(host: str = "",
           ssl_context: _ssl.SSLContext = None,
           resources: Dict[str, str] = {}) -> None:
     with __lock:
-        global __server
-        if __server is not None:
-            __server.shutdown()
-        __server = http_server.SimpleDispatcherHttpServer(host=(host, port),
-                                                          ssl=ssl,
-                                                          ssl_protocol=ssl_protocol,
-                                                          ssl_check_hostname=ssl_check_hostname,
-                                                          keyfile=keyfile,
-                                                          certfile=certfile,
-                                                          keypass=keypass,
-                                                          ssl_context=ssl_context,
-                                                          resources=resources)
+        global _server
+        if _server is not None:
+            _server.shutdown()
+        _server = http_server.SimpleDispatcherHttpServer(host=(host, port),
+                                                         ssl=ssl,
+                                                         ssl_protocol=ssl_protocol,
+                                                         ssl_check_hostname=ssl_check_hostname,
+                                                         keyfile=keyfile,
+                                                         certfile=certfile,
+                                                         keypass=keypass,
+                                                         ssl_context=ssl_context,
+                                                         resources=resources)
 
     filters = _get_filters()
     # filter configuration
     for ft in filters:
-        __server.map_filter(ft["url_pattern"], ft["func"])
+        _server.map_filter(ft["url_pattern"], ft["func"])
 
     request_mappings = _get_request_mappings()
     # request mapping
     for ctr in request_mappings:
-        __server.map_request(ctr)
+        _server.map_controller(ctr)
 
     ws_handlers = _get_websocket_handlers()
 
     for endpoint, clz in ws_handlers.items():
-        __server.map_websocket_handler(endpoint, clz)
+        _server.map_websocket_handler(endpoint, clz)
+
+    err_pages = _get_error_pages()
+    for code, func in err_pages.items():
+        _server.map_error_page(code, func)
 
     # start the server
-    __server.start()
+    _server.start()
+
+
+def is_ready() -> bool:
+    return _server and _server.ready
 
 
 def stop() -> None:
     with __lock:
-        global __server
-        if __server is not None:
+        global _server
+        if _server is not None:
             __logger.info("shutting down server...")
-            __server.shutdown()
-            __server = None
+            _server.shutdown()
+            _server = None
 
 
 @request_map("/favicon.ico")
 def _favicon():
     root = os.path.dirname(os.path.abspath(__file__))
     return StaticFile(f"{root}/favicon.ico", "image/x-icon")
+
+
+def init_wsgi_proxy(resources: Dict[str, str] = {}) -> http_server.WSGIProxy:
+    proxy = http_server.WSGIProxy(res_conf=resources)
+    filters = _get_filters()
+    # filter configuration
+    for ft in filters:
+        proxy.map_filter(ft["url_pattern"], ft["func"])
+
+    request_mappings = _get_request_mappings()
+    # request mapping
+    for ctr in request_mappings:
+        proxy.map_controller(ctr)
+
+    ws_handlers = _get_websocket_handlers()
+
+    for endpoint, clz in ws_handlers.items():
+        proxy.map_websocket_handler(endpoint, clz)
+
+    err_pages = _get_error_pages()
+    for code, func in err_pages.items():
+        proxy.map_error_page(code, func)
+        
+    return proxy
